<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Notification;
use Zeedhi\Framework\DTO\Response\Message;
use Teknisa\MAN\Utilities\Util;
use Teknisa\MAN\Services;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\Util\Functions;

class ProdutoServico extends CrudWithParameterBag {
    
    protected $parameterBag;
    
    public function __construct (ParameterBag $parameterBag, Manager $dataSourceManager, $crudService, Services\ProdutoPorServicoService $ProdutoPorServicoService, Util $util, $entityManager, $environment) {
        $this->parameterBag                     = $parameterBag;
        $this->dataSourceManager                = $dataSourceManager;
        $this->crudService                      = $crudService;
        $this->ProdutoPorServicoService         = $ProdutoPorServicoService;
        $this->util                             = $util;
        $this->entityManager                    = $entityManager;
        $this->environment                      = $environment;
    }
    
    protected $dataSourceNameArray = array( 
        'proServico'            => 'prodServ',
        'servicoFili'           => 'servicoSelect',
        'produtoPorServico'     => 'prodPorServ',
        'tpCons'                => 'select_tipoConsProdServ',
        'selectProducts'        => 'selectActiveProducts',
        'prodServCons'          => 'prodPorServTpCons'
    );

    public function findGridServ(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNameArray['proServico'];
        $this->parameterBagColumns = array('NRORG', 'CDFILIAL', 'CDCAIXA');
        parent::find($request, $response);
    }
    
    public function findServ(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNameArray['servicoFili'];
        $this->parameterBagColumns = array('NRORG', 'CDFILIAL');
        parent::find($request, $response);
    }
    
    
    public function saveServ(DTO\Request\DataSet $request, DTO\Response $response) {
        try {
            $dataSet = $request->getDataSet();
    	    $params = $this->util->getParamsAsArray($request);
            $dataSet->setDataSourceName($this->dataSourceNameArray['proServico']);
            
            if($params[0]['__is_new']){
                if($this->ProdutoPorServicoService->verificaCdServ($params[0]['CDSERVFILI'], $params[0]['NRORG'], $params[0]['CDFILIAL'], $params[0]['CDCAIXA'])){
                    throw new \Exception('Código de serviço já utilizado!');
                }
            }
            
            $persistedRows = $this->dataSourceManager->persist($dataSet);
            $response->addDataSet(new DataSet($this->dataSourceNameArray['proServico'], $persistedRows));
            
        } catch (\Exception $e) {
             $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function deleteServ(DTO\Request\DataSet $request,DTO\Response $response) {
    	try {
    	    $this->dataSourceName = $this->dataSourceNameArray['proServico'];
    	    $params = $this->util->getParamsAsArray($request);
    	    $params['NRORG'] = $this->environment->getNrOrgTrab();
            $this->ProdutoPorServicoService->deleteProdServCascade($params[0]['CDSERVFILI'], $params['NRORG'], $params[0]['CDFILIAL'], $params[0]['CDCAIXA']);
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
    
    public function findCons(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNameArray['tpCons'];
        $this->parameterBagColumns = array('NRORG', 'CDFILIAL');
        parent::find($request, $response);
    }
    
    public function findActiveProducts(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNameArray['selectProducts'];
        $this->parameterBagColumns = array('NRORG');
        parent::find($request, $response);
    }
    
    public function findProd(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNameArray['produtoPorServico'];
        $this->parameterBagColumns = array('NRORG', 'CDFILIAL', 'CDCAIXA', 'CDSERVFILI');
        parent::find($request, $response);
    }
    
    public function saveProd(DTO\Request\DataSet $request, DTO\Response $response){
        $this->dataSourceName = $this->dataSourceNameArray['produtoPorServico'];
        try {
            foreach ($request->getDataSet()->getRows() as $row) {
                $arrayProd = $row['CDPRODUTO'];
                $row['NRTURNO'] = null;
                foreach ($arrayProd as $prod) {
                    $row['CDPRODUTO'] = $prod;
                    $row['__is_new'] = true;
                    $row['changed'] = false;
                    $this->dataSourceManager->persist(new DataSet($this->dataSourceNameArray['produtoPorServico'], array($row)));
                }
            }
            
            $response->addNotification(new Notification("Dados inseridos com sucesso!", Notification::TYPE_SUCCESS));
        } catch (Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function updateProd(DTO\Request\Row $params, DTO\Response $response){
        $rows = $params->getRow();
		try{
            $conditions = array(
    			':CDFILIAL'		=> $rows[0]['CDFILIAL'],
    			':CDCAIXA'		=> $rows[0]['CDCAIXA'],
    			':CDSERVFILI'	=> $rows[0]['CDSERVFILI'],
    			':CDPRODUTO'	=> $rows[0]['CDPRODUTO'],
    			':NRORG'	    => $rows[0]['NRORG'],
    			':QTLIMCONPROD'	=> $rows[0]['QTLIMCONPROD'],
    			':IDCARGAUTOPR' => $rows[0]['IDCARGAUTOPR']
    		);
		    
            $this->ProdutoPorServicoService->updateProd($conditions);
        } catch (\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    }
    
    public function deleteProduto(DTO\Request\DataSet $request,DTO\Response $response) {
        try {
    	    $this->dataSourceName = $this->dataSourceNameArray['produtoPorServico'];
            parent::delete($request,$response);
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
    public function findProdTpConsumidor(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNameArray['prodServCons'];
        $this->parameterBagColumns = array('NRORG', 'CDFILIAL', 'CDCAIXA', 'CDSERVFILI','CDTIPOCONS');
        parent::find($request, $response);
    }
    
    public function saveProdCons(DTO\Request\DataSet $request, DTO\Response $response){
        $this->dataSourceName = $this->dataSourceNameArray['prodServCons'];
        try {
            foreach ($request->getDataSet()->getRows() as $row) {
                $arrayProd = $row['CDPRODUTO'];
                $row['NRTURNO'] = null;
                foreach ($arrayProd as $prod) {
                    $row['CDPRODUTO'] = $prod;
                    $row['__is_new'] = true;
                    $row['changed'] = false;
                    $this->dataSourceManager->persist(new DataSet($this->dataSourceNameArray['prodServCons'], array($row)));
                }
            }
            
            $response->addNotification(new Notification("Dados inseridos com sucesso!", Notification::TYPE_SUCCESS));
        } catch (Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode()));
        }
    }
    
    public function updateProdCons(DTO\Request\Row $params, DTO\Response $response){
        $rows = $params->getRow();
		try{
            $conditions = array(
    			':CDFILIAL'		=> $rows[0]['CDFILIAL'],
    			':CDCAIXA'		=> $rows[0]['CDCAIXA'],
    			':CDSERVFILI'	=> $rows[0]['CDSERVFILI'],
    			':CDPRODUTO'	=> $rows[0]['CDPRODUTO'],
    			':CDTIPOCONS'	=> $rows[0]['CDTIPOCONS'],
    			':NRORG'	    => $rows[0]['NRORG'],
    			':QTLIMCONPRSE'	=> $rows[0]['QTLIMCONPRSE'],
    			':IDCARGAUTOPS' => $rows[0]['IDCARGAUTOPS']
    		);
		    
            $this->ProdutoPorServicoService->updateProdCons($conditions);
        } catch (\Exception $e) {
            $this->entityManager->rollback();
            throw $e;
        }
    }
    
    public function deleteProdutoConsumidor(DTO\Request\DataSet $request,DTO\Response $response) {
        try {
    	    $this->dataSourceName = $this->dataSourceNameArray['prodServCons'];
            parent::delete($request,$response);
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }
    
}