<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response;
use Zeedhi\Framework\DTO\Request;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities;
use \Zeedhi\Framework\Util\Functions;

class RelRentabiProdutoPorEvento {

    protected $RelRentabiProdutoPorEventoService;
    protected $utilService;
    
    public function __construct(Services\RelRentabiProdutoPorEventoService $RelRentabiProdutoPorEventoService, Utilities\Util $utilService) {
        $this->RelRentabiProdutoPorEventoService = $RelRentabiProdutoPorEventoService;
        $this->utilService = $utilService;
    }
    
    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        set_time_limit(120);
        $conditions = $this->utilService->getParamsAsArray($request);
        $conditions = $this->buildParamsFaturamento($conditions);
        $result = [];
        
        if(isset($conditions['CDTIPOCUSTO']) && !empty($conditions['CDTIPOCUSTO'])) {
            $result = $this->RelRentabiProdutoPorEventoService->find($conditions);
    
            $response->addDataSet(new DataSet("RelatorioProdEventos", $result));
            
            return $response;
        }
        
        return $result;
        
    }
    
     public function buildParamsFaturamento($conditions) {
        
        $result = [];
        
        if(isset($conditions['CDFILIAL']) && !empty($conditions['CDFILIAL'])) {
            
            $conditions['CDFILIAL'] = implode('_', $conditions['CDFILIAL']);
            $conditions['TCDFILIAL'] = 'F';
            
            if(!array_key_exists('CDCAIXA', $conditions)) {
                $conditions['CDCAIXA'] = '';
                $conditions['TCDCAIXA'] = 'T';
            } else {
                $conditions['CDCAIXA'] = implode('_', $conditions['CDCAIXA']);
                $conditions['TCDCAIXA'] = '';
            }
            
            if(array_key_exists('DTENTRVENDA', $conditions)) {
                $conditions['DTVENDAINI'] = $conditions['DTENTRVENDA'][0];
                $conditions['DTVENDAFIN'] = $conditions['DTENTRVENDA'][1];
                unset($conditions['DTENTRVENDA']);
            }
            
            if (isset($conditions['INTERVALISTA']) && $conditions['INTERVALISTA'] == 'I'){
              if (empty($conditions['CDARVPRODF'])){
                    $conditions['CDARVPRODF'] = $conditions['CDARVPRODI'];
              }
              $conditions['TCDPRODUTO'] = null;
              $conditions['CDPRODLIST'] = null;
              $conditions['PRODNIV'] = null;
            }else if (isset($conditions['INTERVALISTA']) && $conditions['INTERVALISTA'] == 'D') {
              $conditions['PRODNIV'] = str_replace('%', '', str_replace('.', '', $conditions['PRODNIV'])).'%';
              $conditions['TCDPRODUTO'] = null;
              $conditions['CDPRODLIST'] = null;
              $conditions['CDARVPRODF'] = null;
              $conditions['CDARVPRODI'] = null;
            }
            else if (isset($conditions['INTERVALISTA']) && $conditions['INTERVALISTA'] == 'L'){
              $conditions['CDPRODLIST'] = implode('_', $conditions['CDPRODUTO']);
              $conditions['TCDPRODUTO'] = null;
              $conditions['CDARVPRODF'] = null;
              $conditions['CDARVPRODI'] = null;
              $conditions['PRODNIV'] = null;
            }
            else{
              $conditions['TCDPRODUTO'] = 'T';
              $conditions['CDPRODLIST'] = null;
              $conditions['CDARVPRODF'] = null;
              $conditions['CDARVPRODI'] = null;
              $conditions['PRODNIV'] = null;
            }
            
            if(!isset($conditions['CDEVENTO']) && empty($conditions['CDEVENTO'])) {
                $conditions['CDEVENTO'] = '';
                $conditions['TCDEVENTO'] = 'T';
            } else {
                $conditions['CDEVENTO'] = $conditions['CDEVENTO'];
                $conditions['TCDEVENTO'] = '';
            }
            
            return $conditions;
        }
        return $result;
    }
    
    public function findEvento(DTO\Request\Filter $request, DTO\Response $response) {
        $result = [];
        $conditions = $this->utilService->getParamsAsArray($request);
        
        if(!Functions::arrayKeyExists('CDFILIAL', $conditions)) {
            $conditions['CDFILIAL'] = '';
            $conditions['TCDFILIAL'] = 'T';
        } else {
            $conditions['CDFILIAL'] = implode('_', $conditions['CDFILIAL']);
            $conditions['TCDFILIAL'] = '';
        }
        
        if((!Functions::arrayKeyExists('CDFILICAIXA', $conditions)) || is_null($conditions['CDFILICAIXA'])) {
            $conditions['CDCAIXA'] = '';
            $conditions['TCDCAIXA'] = 'T';
        } else {
            $conditions['CDCAIXA'] = implode('_', $conditions['CDFILICAIXA']);
            $conditions['TCDCAIXA'] = '';
        }
        
        $result = $this->RelRentabiProdutoPorEventoService->findEvento($conditions);
        $response->addDataSet(new DataSet("find_eventos", $result));
        
        return $result;
    }
}