<?php
namespace Teknisa\MAN\Controllers;

use Zeedhi\Framework\Controller\CrudWithParameterBag;
use Zeedhi\Framework\DataSource;
use Zeedhi\Framework\DataSource\DataSet;
use Zeedhi\Framework\DataSource\Manager;
use Zeedhi\Framework\DataSource\ParameterBag;
use Zeedhi\Framework\DTO;
use Teknisa\MAN\Services;
use Teknisa\MAN\Utilities;

class VendasHoraHora extends CrudWithParameterBag {
    protected $dataSourceName = 'vnd55004_relVendasHoraHora';
    protected $parameterBagColumns = array('DTINI', 'HORAINI', 'DTFIM', 'HORAFIM', 'CDFILIAL', 'CDCAIXA');
    protected $VendasHoraHoraService;
    protected $utilService;

    public function __construct (Manager $dataSourceManager, ParameterBag $parameterBag,  Utilities\Util $utilService,  Services\VendasHoraHora $VendasHoraHoraService) {
        parent::__construct($dataSourceManager, $parameterBag);
        $this->utilService = $utilService;
        $this->VendasHoraHoraService = $VendasHoraHoraService;
    }

    private function setTCDandCDcondition(&$conditions, $key, $keyName) {
        if( !array_key_exists($key, $conditions) ) {
            $conditions['T'.$keyName] = 'T';    
            $conditions[$keyName] = null;    
        } else {
            $conditions[$keyName] = '_'.implode('_', $conditions[$keyName] ).'_';
            $conditions['T'.$keyName] = 'F';
            if($key !== $keyName) {
                unset($conditions[$keyName]);
            }
        }
    }

    public function find(DTO\Request\Filter $request, DTO\Response $response) {
        $result = array();
        try {
            $conditions = $this->utilService->getParamsAsArray($request);
            $conditions['__is_report'] = ($request->getFilterCriteria()->getPage() === null); 
            if(isset($conditions['DTHRPEDIDO'])){
                if( array_key_exists('DTMOVTURCAIX', $conditions) ) {
                    $conditions['DTINI'] = $conditions['DTMOVTURCAIX'][0];
                    $conditions['DTFIN'] = $conditions['DTMOVTURCAIX'][1];
                    unset($conditions['DTMOVTURCAIX']);
                }
                if( array_key_exists('LABELFILIAL', $conditions) ) {
                    $conditions['CDFILIAL'] = $conditions['LABELFILIAL'];
                    unset($conditions['LABELFILIAL']);
                }
                if(!is_array($conditions['CDFILIAL'])){
                    $filial = array(
                        $conditions['CDFILIAL']
                    );
                    $conditions['CDFILIAL'] = $filial;
                }
                $conditions['HORAINI'] = str_replace (':', '', substr($conditions['DTHRPEDIDO'], 1, -3));
                $conditions['HORAFIM'] = str_replace (':', '', substr($conditions['DTHRPEDIDOFIM'], 1, -3));
                $conditions['MININI'] = str_replace(':', '', substr($conditions['DTHRPEDIDO'], 3, -1));
                $conditions['MINFIM'] = str_replace(':', '', substr($conditions['DTHRPEDIDOFIM'], 3, -1));
                $conditions['__is_report'] = true;
                $this->setTCDandCDcondition($conditions, 'CDFILIAL', 'CDFILIAL');
                //$this->setTCDandCDcondition($conditions, 'CDLOJA', 'CDLOJA');
                $result = $this->VendasHoraHoraService->getVendasHoraHora($conditions);
            }
            if(isset($result)){
                $response->addDataSet(new DataSet ('vnd55004_relVendasHoraHora', $result));
            }
        } catch (\Exception $e) {
            $response->setError(new DTO\Response\Error($e->getMessage(), $e->getCode(), $e->getTraceAsString()));
        }
    }

    public function findAbertura(DTO\Request\Filter $request, DTO\Response $response) {
        $this->dataSourceName = $this->dataSourceNameFilterAbertura;
        parent::find($request, $response);
    }

}