<?php 

namespace Teknisa\MAN\Services;

use Teknisa\MAN\Utilities;
use \Doctrine\ORM\EntityManager;


class RelLojasSemMovimentacao {
    
	protected $entityManager; 

	public function __construct(EntityManager $entityManager)  {
		$this->entityManager = $entityManager;
	}
	
	private function setParameters($conditions) {
    	return array (
    	      ':NRORG' => $conditions['NRORG'],
              ':CDOPERADOR' => $conditions['CDOPERADOR'],
              ':CDFILIAL' => array_key_exists('CDFILIAL', $conditions) ? implode('_', $conditions['CDFILIAL']) : 'T',
              ':CDGRUPFILI' => array_key_exists('CDGRUPFILI', $conditions) ? implode('_', $conditions['CDGRUPFILI']) : 'T',
              ':DTINICIAL' => array_key_exists('PERIODO', $conditions) ?  $conditions['PERIODO'][0]: 'T',
              ':DTFINAL' => array_key_exists('PERIODO', $conditions) ?  $conditions['PERIODO'][1]: 'T'
        );
    }
    
    public function getLojasParadas($conditions) {
      try{
        $params = $this->setParameters($conditions);
        return $this->entityManager->getConnection()->fetchAll(self::REL_LOJAS_PARADAS, $params);
      }catch (Exception $e){
        throw $e;
      }
    }

  const REL_LOJAS_PARADAS = "
  SELECT DISTINCT LJ.CDFILIAL, LJ.NMFILIAL, LJ.LABELFILIAL, LJ.LABELLOJA,
    LJ.CDLOJA, LJ.NMLOJA, LJ.CDPAIS, LJ.NMPAIS, LJ.SGESTADO, LJ.NMESTADO, 
    LJ.CDMUNICIPIO, LJ.NMMUNICIPIO, LJ.LASTDATE, GP.CDGRUPFILI, GP.NMGRUPFILI
      FROM (SELECT DISTINCT V.CDFILIAL, F.NMFILIAL, V.CDFILIAL || ' - ' || F.NMFILIAL AS LABELFILIAL,  V.CDLOJA || ' - ' || L.NMLOJA AS LABELLOJA,
      V.CDLOJA, L.NMLOJA, E.CDPAIS, E.NMPAIS, E.SGESTADO, E.NMESTADO, E.CDMUNICIPIO, E.NMMUNICIPIO, MAX(V.DTVENDA) AS LASTDATE, V.NRORG
          FROM (SELECT FI.CDFILIAL, FI.NMFILIAL, FO.CDOPERADOR 
            FROM FILIAL FI, FILIOPER  FO
            WHERE (((INSTR(:CDFILIAL, FI.CDFILIAL) <> 0)) OR (:CDFILIAL = 'T'))
             AND FI.NRORG = FI.NRORG
             AND FI.CDFILIAL = FO.CDFILIAL
             AND FI.NRORG = FO.NRORG) F
          JOIN (SELECT EF.CDFILIAL, EF.CDPAIS, P.NMPAIS, EF.SGESTADO, ES.NMESTADO, EF.CDMUNICIPIO, MU.NMMUNICIPIO, EF.NRORG
                  FROM ENDEFILI EF
                  JOIN PAIS P
                    ON EF.CDPAIS = P.CDPAIS
                  JOIN ESTADO ES
                    ON EF.SGESTADO = ES.SGESTADO
                   AND EF.CDPAIS = ES.CDPAIS
                  JOIN MUNICIPIO MU
                    ON EF.CDMUNICIPIO = MU.CDMUNICIPIO
                   AND EF.SGESTADO = MU.SGESTADO
                   AND EF.CDPAIS = MU.CDPAIS          
               ) E
            ON F.CDFILIAL = E.CDFILIAL
          JOIN LOJA L
            ON F.CDFILIAL = L.CDFILIAL
          JOIN VENDA V 
            ON F.CDFILIAL = V.CDFILIAL
            AND L.CDLOJA = V.CDLOJA
         WHERE V.IDSITUVENDA = 'O' AND V.DTENTRVENDA <> TRUNC(SYSDATE)
           AND F.CDOPERADOR = :CDOPERADOR           
         GROUP BY  V.CDFILIAL, F.NMFILIAL, V.CDLOJA, L.NMLOJA, E.CDPAIS, E.NMPAIS, E.SGESTADO, E.NMESTADO,
         E.CDMUNICIPIO, E.NMMUNICIPIO, V.NRORG) LJ
        LEFT JOIN FILGRUPFILI GF
            ON LJ.NRORG = GF.NRORG
           AND LJ.CDFILIAL = GF.CDFILIAL
        LEFT  JOIN GRUPFILI GP
            ON LJ.NRORG  = GP.NRORG 
           AND GF.CDGRUPFILI = GP.CDGRUPFILI
           WHERE (((INSTR(:CDGRUPFILI, GF.CDGRUPFILI) <> 0)) OR (:CDGRUPFILI = 'T'))
           AND ((:DTINICIAL = 'T' AND :DTFINAL = 'T') OR (TRUNC(LJ.LASTDATE) BETWEEN TO_DATE(:DTINICIAL, 'DD/MM/YYYY') AND TO_DATE(:DTFINAL, 'DD/MM/YYYY')))
UNION 
SELECT DISTINCT LJ.CDFILIAL, LJ.NMFILIAL, LJ.LABELFILIAL, LJ.LABELLOJA,
    LJ.CDLOJA, LJ.NMLOJA, LJ.CDPAIS, LJ.NMPAIS, LJ.SGESTADO, LJ.NMESTADO, 
    LJ.CDMUNICIPIO, LJ.NMMUNICIPIO, LJ.LASTDATE, GP.CDGRUPFILI, GP.NMGRUPFILI
      FROM (SELECT DISTINCT V.CDFILIAL, F.NMFILIAL, V.CDFILIAL || ' - ' || F.NMFILIAL AS LABELFILIAL,  V.CDLOJA || ' - ' || L.NMLOJA AS LABELLOJA,
      V.CDLOJA, L.NMLOJA, E.CDPAIS, E.NMPAIS, E.SGESTADO, E.NMESTADO, E.CDMUNICIPIO, E.NMMUNICIPIO, MAX(V.DTVENDA) AS LASTDATE, V.NRORG
          FROM (SELECT FI.CDFILIAL, FI.NMFILIAL, FO.CDOPERADOR 
            FROM FILIAL FI, FILIOPER  FO
            WHERE (((INSTR(:CDFILIAL, FI.CDFILIAL) <> 0)) OR (:CDFILIAL = 'T'))
             AND FI.NRORG = FI.NRORG
             AND FI.CDFILIAL = FO.CDFILIAL
             AND FI.NRORG = FO.NRORG) F
          JOIN (SELECT EF.CDFILIAL, EF.CDPAIS, P.NMPAIS, EF.SGESTADO, ES.NMESTADO, EF.CDMUNICIPIO, MU.NMMUNICIPIO, EF.NRORG
                  FROM ENDEFILI EF
                  JOIN PAIS P
                    ON EF.CDPAIS = P.CDPAIS
                  JOIN ESTADO ES
                    ON EF.SGESTADO = ES.SGESTADO
                   AND EF.CDPAIS = ES.CDPAIS
                  JOIN MUNICIPIO MU
                    ON EF.CDMUNICIPIO = MU.CDMUNICIPIO
                   AND EF.SGESTADO = MU.SGESTADO
                   AND EF.CDPAIS = MU.CDPAIS          
               ) E
            ON F.CDFILIAL = E.CDFILIAL
          JOIN LOJA L
            ON F.CDFILIAL = L.CDFILIAL
          JOIN VENDA V 
            ON F.CDFILIAL = V.CDFILIAL
            AND L.CDLOJA = V.CDLOJA
         WHERE V.IDSITUVENDA = 'O' AND V.DTENTRVENDA <> TRUNC(SYSDATE)
           AND F.CDOPERADOR = :CDOPERADOR           
         GROUP BY  V.CDFILIAL, F.NMFILIAL, V.CDLOJA, L.NMLOJA, E.CDPAIS, E.NMPAIS, E.SGESTADO, E.NMESTADO,
         E.CDMUNICIPIO, E.NMMUNICIPIO, V.NRORG) LJ
        LEFT JOIN FILGRUPFILI GF
            ON LJ.NRORG = GF.NRORG
           AND LJ.CDFILIAL = GF.CDFILIAL    
        LEFT  JOIN GRUPFILI GP
            ON LJ.NRORG  = GP.NRORG 
           AND GF.CDGRUPFILI = GP.CDGRUPFILI
           WHERE (((INSTR(:CDGRUPFILI, GF.CDGRUPFILI) <> 0)) OR (:CDGRUPFILI = 'T'))
           AND ((:DTINICIAL = 'T' AND :DTFINAL = 'T') OR (TRUNC(LJ.LASTDATE) < TO_DATE(:DTINICIAL, 'DD/MM/YYYY')))
  ";
}