<?php
namespace Teknisa\MAN\Services;

use Teknisa\MAN\Utilities;

class Relatorio {

    protected $entityManager; 

    public function __construct(\Doctrine\ORM\EntityManager $entityManager){
        $this->entityManager  = $entityManager;
    }

    public function buildParametersByRelatorio($requestRow, $parameterMapping){
        $reportStrategy = array (
            'ReportName' => $requestRow['__report_name'],
            'ParametersRow' => array ()
        );
        
        
        foreach ($parameterMapping as $fieldName => $paramName) {
            if ($requestRow->has($fieldName)) {
                $reportStrategy['ParametersRow'][$paramName] = $requestRow->get($fieldName);
            } else {
                $reportStrategy['ParametersRow'][$paramName] = null;
            }
        }
        return $reportStrategy;
    }

    public function getTabelaPreco($row) {
        $params = array('DATA' => $row['DATA'], 'NRORG' => $row['NRORG'], 'CDFILIAL' => $row['CDFILIAL'], 'CDLOJA' => $row['CDLOJA']);
        $tabpreco = $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_TABELAPRECOBYLOJA, $params);
        if(count($tabpreco) == 0){
            unset($params['CDLOJA']);
            $tabpreco = $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_TABELAPRECOBYFILIAL, $params);
        }
        return $tabpreco[0];
    }
    
    public function getAllCaixasByFilial($cdfilial, $cdloja, $nrorg) {
        $params = array(
            'CDFILIAL'  => implode('_', $cdfilial),
            'CDLOJA'    => $cdloja === null ? null : implode('_', $cdloja),
            'TCDLOJA'   => $cdloja === null ? 'T' : null,
            'NRORG'     => $nrorg
        );
        
        return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_CAIXAS_BY_FILIAL, $params);
    }
    
    public function getAllLojasByFilial($cdfilial, $nrorg) {
        $params = array(
            'CDFILIAL'  => implode('_', $cdfilial),
            'NRORG'     => $nrorg
        );
        
        return $this->entityManager->getConnection()->fetchAll(Utilities\Query::GET_LOJAS_BY_FILIAL, $params);
    }
    
    public function getAberturas ($params) {
        return $this->entityManager->getConnection()->fetchAll(self::GET_ABERTURAS, $params);
    }
    
    const GET_ABERTURAS = " 
     SELECT * FROM (SELECT F.CDFILIAL || ' - ' || F.NMFILIAL AS LABELUNIDADE, CX.CDLOJA AS LABELLOJA, CX.CDCAIXA    AS LABELCAIXA, 
               OP.CDOPERADOR ||'-' ||OP.NMOPERADOR AS OPERNOME, DECODE (TC.DTFECHCAIX, NULL, 'Aberto', 'Fechado') AS IDSITUACAO,
               TC.CDFILIAL, TC.CDCAIXA, CX.NMCAIXA, TC.CDCAIXA ||' - ' ||CX.NMCAIXA AS CAIXA, TC.DTABERCAIX, TC.DTABERCAIX AS DTABERTUR,
               TC.DTFECHCAIX, TC.CDOPERADOR, OP.NMOPERADOR, MO.VRMOVIVEND, MO.CDTIPORECE, TR.NMTIPORECE, TC.CDOPERABER, O2.NMOPERADOR AS NMOPEFECHA,
               TC.DTMOVTURCAIX, TC.NRECFTURCAIX, TC.NRORG, P.IDPERMANUTVEN, TC.CDFILIAL || '-' || TC.CDCAIXA || '-' || TC.DTABERCAIX AS BIRTABRTFORMAT
          FROM TURCAIXA TC
          JOIN CAIXA CX
            ON (TC.NRORG = CX.NRORG)
           AND (TC.CDFILIAL   = CX.CDFILIAL )
           AND (TC.CDCAIXA    = CX.CDCAIXA )
           
          JOIN FILIAL F
            ON (F.CDFILIAL = TC.CDFILIAL)
           AND F.NRORG = CX.NRORG
           
          JOIN PARAVEND P
            ON (TC.CDFILIAL      = P.CDFILIAL)
           AND (TC.NRORG        = P.NRORG)
           
          LEFT JOIN MOVCAIXA MO
            ON (TC.NRORG       = MO.NRORG)
           AND (TC.DTABERCAIX = MO.DTABERCAIX)
           AND (TC.CDFILIAL   = MO.CDFILIAL )
           AND (TC.CDCAIXA    = MO.CDCAIXA )
           
          LEFT JOIN OPERADOR OP
            ON (TC.NRORG       = OP.NRORG)
           AND (TC.CDOPERADOR = OP.CDOPERADOR)
           
          LEFT JOIN OPERADOR O2
            ON (TC.CDOPERFECH = O2.CDOPERADOR)
           AND (TC.NRORG     = O2.NRORG)
           
          LEFT JOIN TIPORECE TR
            ON (MO.CDTIPORECE = TR.CDTIPORECE)
           AND (MO.NRORG     = TR.NRORG)
          
         WHERE (INSTR(:CDFILIAL, TC.CDFILIAL) <> 0)
           AND ((INSTR(:CDCAIXA, TC.CDCAIXA) <> 0) OR (:TCDCAIXA = 'T'))
           AND ((INSTR(:CDLOJA, CX.CDLOJA) <> 0) OR (:TCDLOJA = 'T'))
           AND (TC.DTMOVTURCAIX BETWEEN :DATAINI AND :DATAFIN)
           AND (TC.NRORG        = :NRORG)
           
           AND (MO.IDTIPOMOVIVE = 'A')
         ORDER BY TC.CDCAIXA, TC.DTABERCAIX) 
         WHERE (UPPER(LABELUNIDADE||LABELLOJA||LABELCAIXA||OPERNOME||IDSITUACAO||DTABERCAIX||DTFECHCAIX) like :ALLFIEDLS  OR :ALLFIEDLS = 'T' )";
}